### library-index

| Family Code         | Description                    |
| --------------------- | ------------------------------ |
| [CUBX0006](https://github.com/spacetimeengineer/mupy/tree/develop/mupy/lib/CUBX0006)  | Very simple cubic famiy for simulating / designing basic blocks. |
| [CUBX0012](https://github.com/spacetimeengineer/mupy/tree/develop/mupy/lib/CUBX0012)  | A very fun original prototype family. To be released 2023. |
| [CUBX0177](https://github.com/spacetimeengineer/mupy/tree/develop/mupy/lib/CUBX0177)  | The CUBX0177 family was developed for simple prototyping and construction. Joinery and bolting based binding. This particular family is really really fun for prototyping. These parts are like legos in some ways but are unlike legos in other ways. |
| [CRSPGR022](https://github.com/spacetimeengineer/mupy/tree/develop/mupy/lib/CRSPGR022) | A family for manufacturing gears. |